import { g as getRenderingRef, f as forceUpdate, h, r as registerInstance } from './index-hPk_vsX1.js';

const KEY = 'proto-autos';
const DATA = 'data';
const PICK = 'pick';
// Examples:
//   get(DATA)
//   get(PICK)
//
const bag = {
    get: (tag) => {
        const key = tag ? `${KEY}-${tag}` : KEY;
        const json = localStorage.getItem(key);
        return json ? JSON.parse(json) : undefined;
    },
    store: (tag, value) => {
        const key = tag ? `${KEY}-${tag}` : KEY;
        const json = JSON.stringify(value);
        localStorage.setItem(key, json);
    },
};

const appendToMap = (map, propName, value) => {
    const items = map.get(propName);
    if (!items) {
        map.set(propName, [value]);
    }
    else if (!items.includes(value)) {
        items.push(value);
    }
};
const debounce = (fn, ms) => {
    let timeoutId;
    return (...args) => {
        if (timeoutId) {
            clearTimeout(timeoutId);
        }
        timeoutId = setTimeout(() => {
            timeoutId = 0;
            fn(...args);
        }, ms);
    };
};

/**
 * Check if a possible element isConnected.
 * The property might not be there, so we check for it.
 *
 * We want it to return true if isConnected is not a property,
 * otherwise we would remove these elements and would not update.
 *
 * Better leak in Edge than to be useless.
 */
const isConnected = (maybeElement) => !('isConnected' in maybeElement) || maybeElement.isConnected;
const cleanupElements = debounce((map) => {
    for (let key of map.keys()) {
        map.set(key, map.get(key).filter(isConnected));
    }
}, 2_000);
const stencilSubscription = () => {
    if (typeof getRenderingRef !== 'function') {
        // If we are not in a stencil project, we do nothing.
        // This function is not really exported by @stencil/core.
        return {};
    }
    const elmsToUpdate = new Map();
    return {
        dispose: () => elmsToUpdate.clear(),
        get: (propName) => {
            const elm = getRenderingRef();
            if (elm) {
                appendToMap(elmsToUpdate, propName, elm);
            }
        },
        set: (propName) => {
            const elements = elmsToUpdate.get(propName);
            if (elements) {
                elmsToUpdate.set(propName, elements.filter(forceUpdate));
            }
            cleanupElements(elmsToUpdate);
        },
        reset: () => {
            elmsToUpdate.forEach((elms) => elms.forEach(forceUpdate));
            cleanupElements(elmsToUpdate);
        },
    };
};

const unwrap = (val) => (typeof val === 'function' ? val() : val);
const createObservableMap = (defaultState, shouldUpdate = (a, b) => a !== b) => {
    const unwrappedState = unwrap(defaultState);
    let states = new Map(Object.entries(unwrappedState ?? {}));
    const handlers = {
        dispose: [],
        get: [],
        set: [],
        reset: [],
    };
    const reset = () => {
        // When resetting the state, the default state may be a function - unwrap it to invoke it.
        // otherwise, the state won't be properly reset
        states = new Map(Object.entries(unwrap(defaultState) ?? {}));
        handlers.reset.forEach((cb) => cb());
    };
    const dispose = () => {
        // Call first dispose as resetting the state would
        // cause less updates ;)
        handlers.dispose.forEach((cb) => cb());
        reset();
    };
    const get = (propName) => {
        handlers.get.forEach((cb) => cb(propName));
        return states.get(propName);
    };
    const set = (propName, value) => {
        const oldValue = states.get(propName);
        if (shouldUpdate(value, oldValue, propName)) {
            states.set(propName, value);
            handlers.set.forEach((cb) => cb(propName, value, oldValue));
        }
    };
    const state = (typeof Proxy === 'undefined'
        ? {}
        : new Proxy(unwrappedState, {
            get(_, propName) {
                return get(propName);
            },
            ownKeys(_) {
                return Array.from(states.keys());
            },
            getOwnPropertyDescriptor() {
                return {
                    enumerable: true,
                    configurable: true,
                };
            },
            has(_, propName) {
                return states.has(propName);
            },
            set(_, propName, value) {
                set(propName, value);
                return true;
            },
        }));
    const on = (eventName, callback) => {
        handlers[eventName].push(callback);
        return () => {
            removeFromArray(handlers[eventName], callback);
        };
    };
    const onChange = (propName, cb) => {
        const unSet = on('set', (key, newValue) => {
            if (key === propName) {
                cb(newValue);
            }
        });
        // We need to unwrap the defaultState because it might be a function.
        // Otherwise we might not be sending the right reset value.
        const unReset = on('reset', () => cb(unwrap(defaultState)[propName]));
        return () => {
            unSet();
            unReset();
        };
    };
    const use = (...subscriptions) => {
        const unsubs = subscriptions.reduce((unsubs, subscription) => {
            if (subscription.set) {
                unsubs.push(on('set', subscription.set));
            }
            if (subscription.get) {
                unsubs.push(on('get', subscription.get));
            }
            if (subscription.reset) {
                unsubs.push(on('reset', subscription.reset));
            }
            if (subscription.dispose) {
                unsubs.push(on('dispose', subscription.dispose));
            }
            return unsubs;
        }, []);
        return () => unsubs.forEach((unsub) => unsub());
    };
    const forceUpdate = (key) => {
        const oldValue = states.get(key);
        handlers.set.forEach((cb) => cb(key, oldValue, oldValue));
    };
    return {
        state,
        get,
        set,
        on,
        onChange,
        use,
        dispose,
        reset,
        forceUpdate,
    };
};
const removeFromArray = (array, item) => {
    const index = array.indexOf(item);
    if (index >= 0) {
        array[index] = array[array.length - 1];
        array.length--;
    }
};

const createStore = (defaultState, shouldUpdate) => {
    const map = createObservableMap(defaultState, shouldUpdate);
    map.use(stencilSubscription());
    return map;
};

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/** Class to realize fetch interceptors */
var FetchInterceptor = function () {
  function FetchInterceptor() {
    var _this = this;

    _classCallCheck(this, FetchInterceptor);

    this.interceptors = [];

    this.fetch = function () {
      for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      return _this.interceptorWrapper.apply(_this, [fetch].concat(args));
    };
  }

  /**
   * add new interceptors
   * @param {(Object|Object[])} interceptors
   */


  _createClass(FetchInterceptor, [{
    key: 'addInterceptors',
    value: function addInterceptors(interceptors) {
      var _this2 = this;

      var removeIndex = [];

      if (Array.isArray(interceptors)) {
        interceptors.map(function (interceptor) {
          removeIndex.push(_this2.interceptors.length);
          return _this2.interceptors.push(interceptor);
        });
      } else if (interceptors instanceof Object) {
        removeIndex.push(this.interceptors.length);
        this.interceptors.push(interceptors);
      }

      this.updateInterceptors();

      return function () {
        return _this2.removeInterceptors(removeIndex);
      };
    }

    /**
     * remove interceptors by indexes
     * @param {number[]} indexes 
     */

  }, {
    key: 'removeInterceptors',
    value: function removeInterceptors(indexes) {
      var _this3 = this;

      if (Array.isArray(indexes)) {
        indexes.map(function (index) {
          return _this3.interceptors.splice(index, 1);
        });
        this.updateInterceptors();
      }
    }

    /**
     * @private
     */

  }, {
    key: 'updateInterceptors',
    value: function updateInterceptors() {
      this.reversedInterceptors = this.interceptors.reduce(function (array, interceptor) {
        return [interceptor].concat(array);
      }, []);
    }

    /**
     * remove all interceptors
     */

  }, {
    key: 'clearInterceptors',
    value: function clearInterceptors() {
      this.interceptors = [];

      this.updateInterceptors();
    }

    /**
     * @private
     */

  }, {
    key: 'interceptorWrapper',
    value: function interceptorWrapper(fetch) {
      for (var _len2 = arguments.length, args = Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
        args[_key2 - 1] = arguments[_key2];
      }

      var promise = Promise.resolve(args);

      this.reversedInterceptors.forEach(function (_ref) {
        var request = _ref.request,
            requestError = _ref.requestError;

        if (request || requestError) {
          promise = promise.then(function () {
            return request.apply(undefined, args);
          }, requestError);
        }
      });

      promise = promise.then(function () {
        return fetch.apply(undefined, args);
      });

      this.reversedInterceptors.forEach(function (_ref2) {
        var response = _ref2.response,
            responseError = _ref2.responseError;

        if (response || responseError) {
          promise = promise.then(response, responseError);
        }
      });

      return promise;
    }
  }]);

  return FetchInterceptor;
}();

/**
 * GraphQL client with fetch api.
 * @extends FetchInterceptor
 */


var FetchQL = function (_FetchInterceptor) {
  _inherits(FetchQL, _FetchInterceptor);

  /**
   * Create a FetchQL instance.
   * @param {Object} options
   * @param {String} options.url - the server address of GraphQL
   * @param {(Object|Object[])=} options.interceptors
   * @param {{}=} options.headers - request headers
   * @param {FetchQL~requestQueueChanged=} options.onStart - callback function of a new request queue
   * @param {FetchQL~requestQueueChanged=} options.onEnd - callback function of request queue finished
   * @param {Boolean=} options.omitEmptyVariables - remove null props(null or '') from the variables
   * @param {Object=} options.requestOptions - addition options to fetch request(refer to fetch api)
   */
  function FetchQL(_ref3) {
    var url = _ref3.url,
        interceptors = _ref3.interceptors,
        headers = _ref3.headers,
        onStart = _ref3.onStart,
        onEnd = _ref3.onEnd,
        _ref3$omitEmptyVariab = _ref3.omitEmptyVariables,
        omitEmptyVariables = _ref3$omitEmptyVariab === undefined ? false : _ref3$omitEmptyVariab,
        _ref3$requestOptions = _ref3.requestOptions,
        requestOptions = _ref3$requestOptions === undefined ? {} : _ref3$requestOptions;

    _classCallCheck(this, FetchQL);

    var _this4 = _possibleConstructorReturn(this, (FetchQL.__proto__ || Object.getPrototypeOf(FetchQL)).call(this));

    _this4.requestObject = Object.assign({}, {
      method: 'POST',
      headers: Object.assign({}, {
        Accept: 'application/json',
        'Content-Type': 'application/json'
      }, headers),
      credentials: 'same-origin'
    }, requestOptions);

    _this4.url = url;

    _this4.omitEmptyVariables = omitEmptyVariables;

    // marker for request queue
    _this4.requestQueueLength = 0;

    // using for caching enums' type
    _this4.EnumMap = {};

    _this4.callbacks = {
      onStart: onStart,
      onEnd: onEnd
    };

    _this4.addInterceptors(interceptors);
    return _this4;
  }

  /**
   * operate a query
   * @param {Object} options
   * @param {String} options.operationName
   * @param {String} options.query
   * @param {Object=} options.variables
   * @param {Object=} options.opts - addition options(will not be passed to server)
   * @param {Boolean=} options.opts.omitEmptyVariables - remove null props(null or '') from the variables
   * @param {Object=} options.requestOptions - addition options to fetch request(refer to fetch api)
   * @returns {Promise}
   * @memberOf FetchQL
   */


  _createClass(FetchQL, [{
    key: 'query',
    value: function query(_ref4) {
      var _this5 = this;

      var operationName = _ref4.operationName,
          _query = _ref4.query,
          variables = _ref4.variables,
          _ref4$opts = _ref4.opts,
          opts = _ref4$opts === undefined ? {} : _ref4$opts,
          _ref4$requestOptions = _ref4.requestOptions,
          requestOptions = _ref4$requestOptions === undefined ? {} : _ref4$requestOptions;

      var options = Object.assign({}, this.requestObject, requestOptions);
      var vars = void 0;
      if (this.omitEmptyVariables || opts.omitEmptyVariables) {
        vars = this.doOmitEmptyVariables(variables);
      } else {
        vars = variables;
      }
      var body = {
        operationName: operationName,
        query: _query,
        variables: vars
      };
      options.body = JSON.stringify(body);

      this.onStart();

      return this.fetch(this.url, options).then(function (res) {
        if (res.ok) {
          return res.json();
        }
        // return an custom error stack if request error
        return {
          errors: [{
            message: res.statusText,
            stack: res
          }]
        };
      }).then(function (_ref5) {
        var data = _ref5.data,
            errors = _ref5.errors;
        return new Promise(function (resolve, reject) {
          _this5.onEnd();

          // if data in response is 'null'
          if (!data) {
            return reject(errors || [{}]);
          }
          // if all properties of data is 'null'
          var allDataKeyEmpty = Object.keys(data).every(function (key) {
            return !data[key];
          });
          if (allDataKeyEmpty) {
            return reject(errors);
          }
          return resolve({ data: data, errors: errors });
        });
      });
    }

    /**
     * get current server address
     * @returns {String}
     * @memberOf FetchQL
     */

  }, {
    key: 'getUrl',
    value: function getUrl() {
      return this.url;
    }

    /**
     * setting a new server address
     * @param {String} url
     * @memberOf FetchQL
     */

  }, {
    key: 'setUrl',
    value: function setUrl(url) {
      this.url = url;
    }

    /**
     * get information of enum type
     * @param {String[]} EnumNameList - array of enums' name
     * @returns {Promise}
     * @memberOf FetchQL
     */

  }, {
    key: 'getEnumTypes',
    value: function getEnumTypes(EnumNameList) {
      var _this6 = this;

      var fullData = {};

      // check cache status
      var unCachedEnumList = EnumNameList.filter(function (element) {
        if (_this6.EnumMap[element]) {
          // enum has been cached
          fullData[element] = _this6.EnumMap[element];
          return false;
        }
        return true;
      });

      // immediately return the data if all enums have been cached
      if (!unCachedEnumList.length) {
        return new Promise(function (resolve) {
          resolve({ data: fullData });
        });
      }

      // build query string for uncached enums
      var EnumTypeQuery = unCachedEnumList.map(function (type) {
        return type + ': __type(name: "' + type + '") {\n        ...EnumFragment\n      }';
      });

      var query = '\n      query {\n        ' + EnumTypeQuery.join('\n') + '\n      }\n      \n      fragment EnumFragment on __Type {\n        kind\n        description\n        enumValues {\n          name\n          description\n        }\n      }';

      var options = Object.assign({}, this.requestObject);
      options.body = JSON.stringify({ query: query });

      this.onStart();

      return this.fetch(this.url, options).then(function (res) {
        if (res.ok) {
          return res.json();
        }
        // return an custom error stack if request error
        return {
          errors: [{
            message: res.statusText,
            stack: res
          }]
        };
      }).then(function (_ref6) {
        var data = _ref6.data,
            errors = _ref6.errors;
        return new Promise(function (resolve, reject) {
          _this6.onEnd();

          // if data in response is 'null' and have any errors
          if (!data) {
            return reject(errors || [{ message: 'Do not get any data.' }]);
          }
          // if all properties of data is 'null'
          var allDataKeyEmpty = Object.keys(data).every(function (key) {
            return !data[key];
          });
          if (allDataKeyEmpty && errors && errors.length) {
            return reject(errors);
          }
          // merge enums' data
          var passData = Object.assign(fullData, data);
          // cache new enums' data
          Object.keys(data).map(function (key) {
            _this6.EnumMap[key] = data[key];
            return key;
          });
          return resolve({ data: passData, errors: errors });
        });
      });
    }

    /**
     * calling on a request starting
     * if the request belong to a new queue, call the 'onStart' method
     */

  }, {
    key: 'onStart',
    value: function onStart() {
      this.requestQueueLength++;
      if (this.requestQueueLength > 1 || !this.callbacks.onStart) {
        return;
      }
      this.callbacks.onStart(this.requestQueueLength);
    }

    /**
     * calling on a request ending
     * if current queue finished, calling the 'onEnd' method
     */

  }, {
    key: 'onEnd',
    value: function onEnd() {
      this.requestQueueLength--;
      if (this.requestQueueLength || !this.callbacks.onEnd) {
        return;
      }
      this.callbacks.onEnd(this.requestQueueLength);
    }

    /**
     * Callback of requests queue changes.(e.g. new queue or queue finished)
     * @callback FetchQL~requestQueueChanged
     * @param {number} queueLength - length of current request queue
     */

    /**
     * remove empty props(null or '') from object
     * @param {Object} input
     * @returns {Object}
     * @memberOf FetchQL
     * @private
     */

  }, {
    key: 'doOmitEmptyVariables',
    value: function doOmitEmptyVariables(input) {
      var _this7 = this;

      var nonEmptyObj = {};
      Object.keys(input).map(function (key) {
        var value = input[key];
        if (typeof value === 'string' && value.length === 0 || value === null || value === undefined) {
          return key;
        } else if (value instanceof Object) {
          nonEmptyObj[key] = _this7.doOmitEmptyVariables(value);
        } else {
          nonEmptyObj[key] = value;
        }
        return key;
      });
      return nonEmptyObj;
    }
  }]);

  return FetchQL;
}(FetchInterceptor);

// --------------------------------------------------------[ mutable store ]
const storeDef = {
    loading: false,
    error: undefined,
    data: undefined,
    pick: 0,
    dealer: undefined,
};
const { state } = createStore(storeDef);
// --------------------------------------------------------[ utility ]
const clearStore = (loading = false) => {
    state.loading = loading;
    state.error = undefined;
    state.pick = 0;
    state.data = undefined;
    state.dealer = undefined;
};
// --------------------------------------------------------[ processing ]
const processData = (next) => {
    if (next) {
        const { pick } = state;
        if (pick != undefined) {
            state.dealer = next.list[pick];
        }
        else {
            state.dealer = undefined;
        }
        state.data = next;
        state.loading = false;
    }
    else {
        state.data = undefined;
        state.loading = false;
    }
};
const processPick = (next) => {
    const { data } = state;
    if (data && next !== undefined) {
        state.pick = next;
        state.dealer = data.list[next];
    }
    else {
        state.pick = 0;
        state.dealer = undefined;
    }
};
// --------------------------------------------------------[ graphQL ]
var Client = new FetchQL({
    url: 'https://gt-forza.vercel.app/graphql',
});
const GET_UUID = `
  query Uuid($count: Int!) {
    uuid(count: $count)
  }
`;
const GET_DEALERS = `
  query Solution($id: String!) {
    solution(id: $id) {
      id
      data {
        dealers {
          dealerId
          name
          vehicles {
            vin
            year
            make
            model
            color
          }
        }
      }
    }
  }
`;
// --------------------------------------------------------[ actions ]
const initApp = () => {
    clearStore();
    // this retrieves the last data we stored in the bag...
    const data = bag.get(DATA);
    const pick = bag.get(PICK);
    if (data) {
        processData(data);
        if (pick) {
            processPick(pick);
        }
    }
    else {
        refresh();
    }
};
const refresh = () => {
    clearStore(true);
    bag.store(PICK, 0);
    const count = 1;
    // NOTE:  step 1 - fetch a UUID...
    Client.query({
        operationName: 'Uuid',
        query: GET_UUID,
        variables: { count },
    }).then(response => {
        const id = response.data.uuid[0];
        // NOTE:  step 2 - fetch a solution with this id...
        Client.query({
            operationName: 'Solution',
            query: GET_DEALERS,
            variables: { id },
        }).then(response => {
            const list = JSON.parse(JSON.stringify(response.data.solution.data.dealers));
            const solution = { id, list };
            bag.store(DATA, solution);
            processData(solution);
        });
    });
};
const updatePick = (pick) => {
    bag.store(PICK, pick);
    processPick(pick);
};
const actions = {
    initApp,
    refresh,
    updatePick,
};

// WARNING:  generated file...
const TW_VERSION = '4.1.7';

const tw = (...classes) => {
    return classes.filter(Boolean).join(' ');
};

const DealerCard = props => {
    const { value } = props;
    const { dealerId, name, vehicles } = value || {};
    const count = vehicles ? vehicles.length : 0;
    return (h("div", { class: tw('flex flex-wrap content-center', 'mb-4 rounded-lg bg-blue-200 p-4', 'border border-solid border-blue-400') },
        h("label", { class: "text-xl font-bold" },
            name ? `${name} ` : '',
            h("sup", null, count ? count : '')),
        h("label", { class: "ml-auto self-center text-right text-sm" }, dealerId ? dealerId : '')));
};

const racingRegex = /^\#[0-9]*/;
const isRacing = (model) => {
    return model.match(racingRegex) != null;
};
const isExotic = (year) => {
    return year === 2554;
};
const isModern = (year) => {
    return year > 2010;
};
const VehicleCard = props => {
    const { vin, make, model, year, color } = props.value || {};
    return (h("div", { class: tw('flex align-middle', 'mb-1 rounded-lg p-4', 'border border-solid', isExotic(year)
            ? 'border-clrs-navy bg-clrs-navy text-clrs-white'
            : isRacing(model)
                ? 'border-yellow-600 bg-yellow-300'
                : isModern(year)
                    ? 'border-green-600 bg-green-200'
                    : 'border-gray-600 bg-gray-300') },
        h("div", { class: "mr-1.5 flex flex-col" },
            h("label", { class: "mb-2 text-xs" }, vin ? vin : ''),
            h("label", { class: "text-lg font-bold" }, make ? make : ''),
            h("label", { class: "mb-2 text-sm italic" }, model ? model : ''),
            h("label", null,
                year ? year : '',
                ", ",
                color ? color : ''),
            h("label", null, isExotic(year)
                ? '- exotic... [ Sierra 117 ]'
                : isRacing(model)
                    ? '- track only...'
                    : '')),
        h("proto-ikon-loader", { class: "ikon ml-auto self-center", name: make, label: make.toLowerCase() })));
};

const VehicleList = props => {
    const { list } = props;
    const count = list.length;
    if (count === 0)
        return '';
    return (h("div", { class: "flex flex-col" }, count ? list.map(vehicle => h(VehicleCard, { value: vehicle })) : ''));
};

const DealerView = props => {
    const { dealer } = props;
    const { vehicles } = dealer || { vehicles: [] };
    const list = vehicles;
    if (!dealer)
        return '';
    return (h("div", { class: "flex flex-col" },
        h(DealerCard, { value: dealer }),
        h(VehicleList, { list: list })));
};

const url = 'https://eswat2.dev';
const who = 'eswat2';
const Eswat2Io = _props => {
    return (h("a", { class: "absolute right-0 top-0 text-clrs-gray hover:text-clrs-navy", href: url, "aria-label": who, target: "blank", title: who },
        h("proto-ikon-loader", { name: "fingerprint", size: 24, label: "eswat2" })));
};

const Footer = _props => {
    return (h("div", { class: "mb-4 mr-2 mt-2 flex flex-row" },
        h("label", { class: "ml-auto align-top text-xs italic text-clrs-slate4" },
            "Tailwind ",
            TW_VERSION)));
};

const Header = props => {
    const { label } = props;
    return (h("h1", { class: tw('text-center uppercase text-clrs-red', 'mb-11 ml-0 mr-0 mt-11', 'text-6xl font-thin') }, label));
};

const Spinner = props => {
    const hex = props.hex || 'currentColor';
    const klass = props.class || '';
    const label = props.label || 'loading...';
    const size = props.size || 24;
    return (h("svg", { class: tw(klass, 'animate-spin'), width: size, height: size, fill: "none", viewBox: "0 0 24 24", role: "img", "aria-label": "title" },
        h("title", null, label),
        h("g", null,
            h("circle", { class: "opacity-25", cx: "12", cy: "12", r: "10", stroke: hex, "stroke-width": "4" }),
            h("path", { class: "opacity-75", fill: hex, d: "M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z" })),
        h("path", { d: "M0 0h24v24H0z", fill: "none" })));
};

const ToolBar = _props => {
    const { loading, pick, data } = state || {};
    const { list } = data || { list: [] };
    const max = list.length - 1;
    if (loading)
        return '';
    return (h("div", { class: "flex" },
        h("div", { class: "refresh hover:text-clrs-red md:w-auto", onClick: () => actions.refresh() },
            h("proto-ikon-loader", { name: "refresh", size: 24 })),
        h("div", { class: tw('ml-auto inline-flex justify-end', 'border border-solid border-gray-600', 'rounded-md') }, list.map((dealer, indx) => (h("button", { class: tw('h-8 w-8 border-none font-bold', indx == 0
                ? 'rounded-bl-md rounded-br-none rounded-tl-md rounded-tr-none'
                : indx == max
                    ? 'rounded-bl-none rounded-br-md rounded-tl-none rounded-tr-md'
                    : 'rounded-none', pick == indx
                ? 'bg-clrs-red text-white'
                : 'bg-clrs-yellow text-clrs-navy'), onClick: () => actions.updatePick(indx), title: `${dealer.name} (${dealer.vehicles.length})` }, indx + 1))))));
};

const shadowCss = "/*! tailwindcss v4.1.7 | MIT License | https://tailwindcss.com */\n@layer properties;\n@layer theme, base, components, utilities;\n@layer theme {\n  :root,\n  :host {\n    --font-sans:\n      ui-sans-serif, system-ui, sans-serif, 'Apple Color Emoji',\n      'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji';\n    --color-yellow-300: oklch(90.5% 0.182 98.111);\n    --color-yellow-600: oklch(68.1% 0.162 75.834);\n    --color-green-200: oklch(92.5% 0.084 155.995);\n    --color-green-600: oklch(62.7% 0.194 149.214);\n    --color-blue-200: oklch(88.2% 0.059 254.128);\n    --color-blue-400: oklch(70.7% 0.165 254.624);\n    --color-gray-300: oklch(87.2% 0.01 258.338);\n    --color-gray-600: oklch(44.6% 0.03 256.802);\n    --color-white: #fff;\n    --spacing: 0.25rem;\n    --text-xs: 0.75rem;\n    --text-xs--line-height: calc(1 / 0.75);\n    --text-sm: 0.875rem;\n    --text-sm--line-height: calc(1.25 / 0.875);\n    --text-lg: 1.125rem;\n    --text-lg--line-height: calc(1.75 / 1.125);\n    --text-xl: 1.25rem;\n    --text-xl--line-height: calc(1.75 / 1.25);\n    --text-6xl: 3.75rem;\n    --text-6xl--line-height: 1;\n    --font-weight-thin: 100;\n    --font-weight-bold: 700;\n    --radius-md: 0.375rem;\n    --radius-lg: 0.5rem;\n    --animate-spin: spin 1s linear infinite;\n  }\n}\n@layer utilities {\n  .absolute {\n    position: absolute;\n  }\n  .relative {\n    position: relative;\n  }\n  .top-0 {\n    top: calc(var(--spacing) * 0);\n  }\n  .right-0 {\n    right: calc(var(--spacing) * 0);\n  }\n  .m-6 {\n    margin: calc(var(--spacing) * 6);\n  }\n  .mt-2 {\n    margin-top: calc(var(--spacing) * 2);\n  }\n  .mt-4 {\n    margin-top: calc(var(--spacing) * 4);\n  }\n  .mt-11 {\n    margin-top: calc(var(--spacing) * 11);\n  }\n  .mr-0 {\n    margin-right: calc(var(--spacing) * 0);\n  }\n  .mr-1\\.5 {\n    margin-right: calc(var(--spacing) * 1.5);\n  }\n  .mr-2 {\n    margin-right: calc(var(--spacing) * 2);\n  }\n  .mb-1 {\n    margin-bottom: calc(var(--spacing) * 1);\n  }\n  .mb-2 {\n    margin-bottom: calc(var(--spacing) * 2);\n  }\n  .mb-4 {\n    margin-bottom: calc(var(--spacing) * 4);\n  }\n  .mb-11 {\n    margin-bottom: calc(var(--spacing) * 11);\n  }\n  .ml-0 {\n    margin-left: calc(var(--spacing) * 0);\n  }\n  .ml-auto {\n    margin-left: auto;\n  }\n  .flex {\n    display: flex;\n  }\n  .inline-flex {\n    display: inline-flex;\n  }\n  .h-8 {\n    height: calc(var(--spacing) * 8);\n  }\n  .w-8 {\n    width: calc(var(--spacing) * 8);\n  }\n  .animate-spin {\n    animation: var(--animate-spin);\n  }\n  .flex-col {\n    flex-direction: column;\n  }\n  .flex-row {\n    flex-direction: row;\n  }\n  .flex-wrap {\n    flex-wrap: wrap;\n  }\n  .content-center {\n    align-content: center;\n  }\n  .justify-end {\n    justify-content: flex-end;\n  }\n  .self-center {\n    align-self: center;\n  }\n  .rounded-lg {\n    border-radius: var(--radius-lg);\n  }\n  .rounded-md {\n    border-radius: var(--radius-md);\n  }\n  .rounded-none {\n    border-radius: 0;\n  }\n  .rounded-tl-md {\n    border-top-left-radius: var(--radius-md);\n  }\n  .rounded-tl-none {\n    border-top-left-radius: 0;\n  }\n  .rounded-tr-md {\n    border-top-right-radius: var(--radius-md);\n  }\n  .rounded-tr-none {\n    border-top-right-radius: 0;\n  }\n  .rounded-br-md {\n    border-bottom-right-radius: var(--radius-md);\n  }\n  .rounded-br-none {\n    border-bottom-right-radius: 0;\n  }\n  .rounded-bl-md {\n    border-bottom-left-radius: var(--radius-md);\n  }\n  .rounded-bl-none {\n    border-bottom-left-radius: 0;\n  }\n  .border {\n    border-style: var(--tw-border-style);\n    border-width: 1px;\n  }\n  .border-r-0 {\n    border-right-style: var(--tw-border-style);\n    border-right-width: 0px;\n  }\n  .border-b-0 {\n    border-bottom-style: var(--tw-border-style);\n    border-bottom-width: 0px;\n  }\n  .border-l-0 {\n    border-left-style: var(--tw-border-style);\n    border-left-width: 0px;\n  }\n  .border-none {\n    --tw-border-style: none;\n    border-style: none;\n  }\n  .border-solid {\n    --tw-border-style: solid;\n    border-style: solid;\n  }\n  .border-blue-400 {\n    border-color: var(--color-blue-400);\n  }\n  .border-clrs-navy {\n    border-color: var(--clrs-navy, #001f3f);\n  }\n  .border-gray-300 {\n    border-color: var(--color-gray-300);\n  }\n  .border-gray-600 {\n    border-color: var(--color-gray-600);\n  }\n  .border-green-600 {\n    border-color: var(--color-green-600);\n  }\n  .border-yellow-600 {\n    border-color: var(--color-yellow-600);\n  }\n  .bg-blue-200 {\n    background-color: var(--color-blue-200);\n  }\n  .bg-clrs-navy {\n    background-color: var(--clrs-navy, #001f3f);\n  }\n  .bg-clrs-red {\n    background-color: var(--clrs-red, #ff4136);\n  }\n  .bg-clrs-yellow {\n    background-color: var(--clrs-yellow, #ffdc00);\n  }\n  .bg-gray-300 {\n    background-color: var(--color-gray-300);\n  }\n  .bg-green-200 {\n    background-color: var(--color-green-200);\n  }\n  .bg-yellow-300 {\n    background-color: var(--color-yellow-300);\n  }\n  .p-4 {\n    padding: calc(var(--spacing) * 4);\n  }\n  .text-center {\n    text-align: center;\n  }\n  .text-right {\n    text-align: right;\n  }\n  .align-middle {\n    vertical-align: middle;\n  }\n  .align-top {\n    vertical-align: top;\n  }\n  .font-sans {\n    font-family: var(--font-sans);\n  }\n  .text-6xl {\n    font-size: var(--text-6xl);\n    line-height: var(--tw-leading, var(--text-6xl--line-height));\n  }\n  .text-lg {\n    font-size: var(--text-lg);\n    line-height: var(--tw-leading, var(--text-lg--line-height));\n  }\n  .text-sm {\n    font-size: var(--text-sm);\n    line-height: var(--tw-leading, var(--text-sm--line-height));\n  }\n  .text-xl {\n    font-size: var(--text-xl);\n    line-height: var(--tw-leading, var(--text-xl--line-height));\n  }\n  .text-xs {\n    font-size: var(--text-xs);\n    line-height: var(--tw-leading, var(--text-xs--line-height));\n  }\n  .font-bold {\n    --tw-font-weight: var(--font-weight-bold);\n    font-weight: var(--font-weight-bold);\n  }\n  .font-thin {\n    --tw-font-weight: var(--font-weight-thin);\n    font-weight: var(--font-weight-thin);\n  }\n  .text-clrs-gray {\n    color: var(--clrs-gray, #aaaaaa);\n  }\n  .text-clrs-navy {\n    color: var(--clrs-navy, #001f3f);\n  }\n  .text-clrs-red {\n    color: var(--clrs-red, #ff4136);\n  }\n  .text-clrs-slate4 {\n    color: var(--clrs-slate4, #4e5964);\n  }\n  .text-clrs-white {\n    color: var(--clrs-white, #ffffff);\n  }\n  .text-white {\n    color: var(--color-white);\n  }\n  .uppercase {\n    text-transform: uppercase;\n  }\n  .italic {\n    font-style: italic;\n  }\n  .opacity-25 {\n    opacity: 25%;\n  }\n  .opacity-75 {\n    opacity: 75%;\n  }\n  .shadow {\n    --tw-shadow:\n      0 1px 3px 0 var(--tw-shadow-color, rgb(0 0 0 / 0.1)),\n      0 1px 2px -1px var(--tw-shadow-color, rgb(0 0 0 / 0.1));\n    box-shadow:\n      var(--tw-inset-shadow), var(--tw-inset-ring-shadow),\n      var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow);\n  }\n  .hover\\:text-clrs-navy {\n    &:hover {\n      @media (hover: hover) {\n        color: var(--clrs-navy, #001f3f);\n      }\n    }\n  }\n  .hover\\:text-clrs-red {\n    &:hover {\n      @media (hover: hover) {\n        color: var(--clrs-red, #ff4136);\n      }\n    }\n  }\n  .md\\:w-auto {\n    @media (width >= 48rem) {\n      width: auto;\n    }\n  }\n}\n@layer components {\n  .ds1-main {\n    margin: calc(var(--spacing) * 6);\n    display: flex;\n    flex-direction: column;\n    font-family: var(--font-sans);\n    color: var(--clrs-navy, #001f3f);\n    -webkit-font-smoothing: antialiased;\n    -moz-osx-font-smoothing: grayscale;\n  }\n}\n.ikon {\n  height: 96px;\n  width: 96px;\n}\n@media (min-width: 500px) {\n  .ikon {\n    height: 144px;\n    width: 144px;\n  }\n}\n@media (min-width: 700px) {\n  .ikon {\n    height: 192px;\n    width: 192px;\n  }\n}\n@keyframes spin {\n  to {\n    transform: rotate(360deg);\n  }\n}\n@layer properties {\n  @supports ((-webkit-hyphens: none) and (not (margin-trim: inline))) or\n    ((-moz-orient: inline) and (not (color: rgb(from red r g b)))) {\n    *,\n    ::before,\n    ::after,\n    ::backdrop {\n      --tw-border-style: solid;\n      --tw-font-weight: initial;\n      --tw-shadow: 0 0 #0000;\n      --tw-shadow-color: initial;\n      --tw-shadow-alpha: 100%;\n      --tw-inset-shadow: 0 0 #0000;\n      --tw-inset-shadow-color: initial;\n      --tw-inset-shadow-alpha: 100%;\n      --tw-ring-color: initial;\n      --tw-ring-shadow: 0 0 #0000;\n      --tw-inset-ring-color: initial;\n      --tw-inset-ring-shadow: 0 0 #0000;\n      --tw-ring-inset: initial;\n      --tw-ring-offset-width: 0px;\n      --tw-ring-offset-color: #fff;\n      --tw-ring-offset-shadow: 0 0 #0000;\n    }\n  }\n}\n";

const ProtoAutos = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.tag = 'proto-autos';
    }
    componentDidLoad() {
        actions.initApp();
    }
    render() {
        const { loading, dealer } = state;
        return (h("main", { key: 'eb918bee95389cd4c78c6a7b3134ada507c5a042', id: "app", class: "ds1-main relative" }, h(Eswat2Io, { key: 'efa617ee04ddd6c58650d1cf4d00f899c3520efa' }), h(Header, { key: '6762516c1c9fc2d4490e9343d75f4f09f657fae6', label: "Auto Dealers" }), h(ToolBar, { key: 'ce1aeeb560729f66726b859d6f9d5a4a410703b1' }), loading ? (h(Spinner, null)) : (h("hr", { class: tw('mb-4 ml-0 mr-0 mt-4', 'border-solid border-gray-300', 'border-b-0 border-l-0 border-r-0') })), h(DealerView, { key: '63ef8ba16a60533a147c06e126442e9f2481f8fe', dealer: dealer }), h(Footer, { key: '00d32c34fcf933386a5e5f920e09f02f95dbfbf1' })));
    }
};
ProtoAutos.style = shadowCss;

export { ProtoAutos as proto_autos };
